check_target_label_and_n_target_samples
=====================================================================================

.. currentmodule:: imbalanced_ensemble.utils

.. autofunction:: check_target_label_and_n_target_samples

.. include:: ../../../back_references/imbalanced_ensemble.utils.check_target_label_and_n_target_samples.examples

.. raw:: html

    <div style='clear:both'></div>